@@ -11,12 +11,12 @@ require Exporter;
 
 our @ISA = qw(Exporter AudioFile::Info Template::Plugin);
 
-our $VERSION = '1.5.1';
+our $VERSION = sprintf "%d.%02d", '$Revision: 1.3 $ ' =~ /(\d+)\.(\d+)/;
 
 sub new {
-  my ($class, $context, $file, $params) = @_;
+  my ($class, $context, $file) = @_;
 
-  my $self = $class->SUPER::new($file, $params);
+  my $self = $class->SUPER::new($file);
 
   return $self;
 }
@@ -72,7 +72,6 @@ like this.
 
     $tt->process('song.tt', { file => $_ })
       or die $tt->error;
-  }
 
 There are, of course, many other ways to do it.
 
